import type { Metadata, Viewport } from "next";
import { Rubik } from "next/font/google";
import NextTopLoader from "nextjs-toploader";

import "./globals.css";

import Sidebar from "@/components/sidebar";
import { getPlaylists } from "@/lib/playlists";

const rubik = Rubik({ subsets: ["latin"] });

export const metadata: Metadata = {
	title: {
		template: "%s – Vybr",
		default: "Vybr",
	},
	metadataBase: new URL("https://vybr.net"),
	description: "Music App lol.",
};

export const viewport: Viewport = {
	themeColor: "#959EEE",
};

export default async function Layout({
	children,
}: {
	children: React.ReactNode;
}) {
	const playlists = await getPlaylists();

	return (
		<html lang="en">
			<body className={rubik.className}>
				<NextTopLoader color="#959EEE" showSpinner={false} />

				<div className="grid h-[100dvh] select-none grid-cols-[280px,1fr]">
					<Sidebar playlists={playlists} />

					<div className="p-8">
						<header className="mb-8"></header>

						{children}
					</div>
				</div>
			</body>
		</html>
	);
}
