import { Metadata } from "next";
import { Suspense } from "react";

import { getUser } from "@/lib/users";
import { UserPlaylists } from "./playlists";
import { PlaylistsSkeleton } from "./skeleton";

interface PlaylistProps {
	params: {
		user_id: string;
	};
}

export async function generateMetadata({
	params,
}: PlaylistProps): Promise<Metadata> {
	const playlist = await getUser(params.user_id);

	return {
		title: playlist.name,
	};
}

export default async function Playlist({ params }: PlaylistProps) {
	const user = await getUser(params.user_id);

	return (
		<div>
			<header className="mb-12 flex items-center gap-8 border-b pb-12">
				<div className="h-48 w-48 rounded-md border bg-secondary" />
				<div className="flex flex-col gap-4">
					<h2 className="text-3xl font-bold">{user.name}</h2>
				</div>
			</header>

			<section>
				<h2 className="mb-4 text-2xl font-bold">Public playlists</h2>

				<Suspense fallback={<PlaylistsSkeleton />}>
					<UserPlaylists user_id={params.user_id} />
				</Suspense>
			</section>
		</div>
	);
}
