import {
	PopiconsHomeMinimalLine,
	PopiconsMusicNoteLine,
	PopiconsSearchLine,
} from "@popicons/react";
import Link from "next/link";

import { LinkItem } from "@/components/sidebar/link-item";
import { Playlist } from "@/lib/playlists";
import Logo from "../logo";
import CreatePlaylist from "./create-playlist";
import User from "./user";
import {
	ContextMenu,
	ContextMenuContent,
	ContextMenuItem,
	ContextMenuSeparator,
	ContextMenuSub,
	ContextMenuSubContent,
	ContextMenuSubTrigger,
	ContextMenuTrigger,
} from "../ui/context-menu";

const navItems = [
	{
		name: "Library",
		icon: PopiconsHomeMinimalLine,
		href: "/",
	},
	{
		name: "Search",
		icon: PopiconsSearchLine,
		href: "/search",
	},
];

export default function Sidebar({ playlists }: { playlists: Playlist[] }) {
	return (
		<aside className="flex w-full flex-col gap-8 border-r bg-secondary px-4 py-8">
			<Link
				href="/"
				className="flex items-center justify-center gap-4 text-3xl font-bold text-accent transition-transform hover:scale-105"
			>
				<Logo size="48" />
				<span>Vybr</span>
			</Link>

			<hr />

			<User />

			<nav>
				{navItems.map((item) => (
					<LinkItem
						key={item.href}
						name={item.name}
						href={item.href}
						icon={<item.icon />}
					/>
				))}
			</nav>

			<nav>
				<header className="mb-4 flex items-center justify-between text-sm uppercase tracking-widest text-secondary">
					My collection
				</header>
			</nav>

			<nav>
				<header className="mb-4 flex items-center justify-between text-sm uppercase tracking-widest text-secondary">
					Playlists
					<CreatePlaylist />
				</header>

				{playlists.map((playlist) => {
					const href = `/playlists/${playlist.id}`;

					return (
						<ContextMenu key={playlist.id}>
							<ContextMenuTrigger>
								<LinkItem
									name={playlist.name}
									href={href}
									icon={<PopiconsMusicNoteLine />}
								/>
							</ContextMenuTrigger>
							<ContextMenuContent className="w-48">
								<ContextMenuItem>Play now</ContextMenuItem>
								<ContextMenuItem>Shuffle</ContextMenuItem>
								<ContextMenuSeparator />
								<ContextMenuItem>Edit</ContextMenuItem>
								<ContextMenuSeparator />
								<ContextMenuSub>
									<ContextMenuSubTrigger>Share</ContextMenuSubTrigger>
									<ContextMenuSubContent>
										<ContextMenuItem>Copy link</ContextMenuItem>
										<ContextMenuItem>Share on Twitter</ContextMenuItem>
									</ContextMenuSubContent>
								</ContextMenuSub>
							</ContextMenuContent>
						</ContextMenu>
					);
				})}
			</nav>
		</aside>
	);
}
