"use client";

import { FunctionComponent, SVGProps, cloneElement } from "react";
import { usePathname } from "next/navigation";
import Link from "next/link";
import { cn } from "@/lib/utils";

interface LinkItemProps {
	name: string;
	href: string;
	icon: JSX.Element;
}

export function LinkItem({ name, href, icon: Icon }: LinkItemProps) {
	const pathname = usePathname();

	const active = href === pathname;

	return (
		<Link
			href={href}
			className={cn(
				"mb-2 flex h-10 items-center gap-4 rounded-md px-4 text-secondary transition-colors hover:bg-tertiary focus:outline-primary",
				{
					"bg-tertiary": active,
					"text-accent": active,
				},
			)}
		>
			{cloneElement<SVGProps<SVGElement>>(Icon, { fill: "currentColor" })}

			<span className="text-primary">{name}</span>
		</Link>
	);
}
