import { ReactNode, useMemo } from "react";

type Column =
	| string
	| {
			name: string;
			options: ColumnOptions;
	  };

interface ColumnOptions {
	width?: string | number;
}

interface TableProps {
	columns: Record<string, string>;
	row(): ReactNode;
}

export default function Table({ columns, row }: TableProps) {
	const headers = useMemo(() => Object.keys(columns), [columns]);

	return (
		<table className="w-full">
			<thead className="bg-secondary text-sm uppercase text-secondary">
				<tr>
					{headers.map((header) => (
						<th key={header} className="py-2 font-normal">
							<span>{columns[header]}</span>
						</th>
					))}
				</tr>
			</thead>
			<tbody></tbody>
		</table>
	);
}
